@@ -14,13 +14,13 @@ my $case_fold = $] >= 5.016		    ? eval 'sub { return CORE::fc $_[0] }'
 	      : $INC{'Unicode/CaseFold.pm'} ? eval 'sub { return Unicode:CaseFold::fc $_[0] }'
 	      : 			      eval 'sub { return lc $_[0] }';
 
-our $VERSION = '0.47';
+our $VERSION = '0.471';
 
 =head1 NAME
 
 HTTP::Validate - validate and clean HTTP parameter values according to a set of rules
 
-Version 0.47
+Version 0.471
 
 =head1 DESCRIPTION
 
@@ -1455,7 +1455,10 @@ sub add_rules {
 		croak "unknown content type for '$short': you must specify a full content type with '$short=some/type'"
 		    unless $long;
 		
+		croak "type '$short' cannot be specified twice" if defined $rr->{type_map}{$short};
+		
 		$rr->{type_map}{$short} = $long;
+		push @{$rr->{type_list}}, $short;
 	    }
 	    
 	    croak "you must specify at least one value for 'content_type'" unless $rr->{type_map};
@@ -2375,7 +2378,7 @@ sub validate_ruleset {
 		$vr->{content_type} = 'unknown';
 		$vr->{ps}{$param} = 1;
 		$rr->{key} ||= '_content_type';
-		add_error_warn($vr, $rr, 'ERR_MEDIA_TYPE', { param => $param, value => $rr->{type_map} });
+		add_error_warn($vr, $rr, 'ERR_MEDIA_TYPE', { param => $param, value => $rr->{type_list} });
 	    }
 	}
     }
